Skip to contents

Prints out a messages reflecting the progress of the YARF model construction until completion.

Usage

YARF_convergence(yarf_mod, time_delay_in_seconds = 5, trail_pts = 50)

Arguments

yarf_mod

The yarf model object

time_delay_in_seconds

Frequency of messages in seconds. Default is 5 seconds. Minimum is 0.1. NULL indicates it is shown once and then it completes.

trail_pts

If non-null, it will plot a secondary window with only the trees in the last trail_trees number of progress updates defined by time_delay_in_seconds versus error which allows assessing the convergence more closely. Default is 50.

Details

If time_delay_in_seconds is not NULL, running this function once will slow down your model construction since it will forever be calculating OOB statistics after each tree (until completion or until the user stops the function).

Author

Adam Kapelner