Skip to contents

Serializes the model so the user can use save and save.image to write it to a file that can be then loaded into another and/or future R session.

Usage

YARF_serialize(yarf_mod)

Arguments

yarf_mod

The yarf model object

Author

Adam Kapelner