Skip to contents

Computes the out-of-bag (OOB) predictions for the test subset of the training data. This function should only be run once. If it run again you risk adapting your model to the test data which will lead to overfitting and hence a biased out-of-sample performance estimate.

Usage

YARF_update_with_oob_test_results(yarf_mod)

Arguments

yarf_mod

The yarf model object such that YARF_update_with_oob_validation_results has been run before on a user-determined proportion of OOB samples as data validation.

Author

Adam Kapelner