Skip to contents

Computes the out-of-bag (OOB) predictions for the validation subset of the training data. This allows the user to try many different models while still leaving test data for true out-of-sample performance estimation.

Usage

YARF_update_with_oob_validation_results(yarf_mod, validation_proportion = 0.8)

Arguments

yarf_mod

The yarf model object

validation_proportion

The percentage of the data to use for validation data (and the remaining is test data). The default is 80%.

Author

Adam Kapelner