Skip to contents

Gets information about each tree: the number of nodes, number of leaves and maximum depth.

Usage

get_tree_num_nodes_leaves_max_depths(yarf_mod)

Arguments

yarf_mod

The YARF model in which to query

Value

A list with three integer vector components all of which have length equal to the number of trees completes: (1) num_nodes has entries equal to the number of nodes in each tree, (2) num_leaves has entries equal to the number of leaves (terminal nodes) in each tree and (3) max_depths has entries equal to the maximum depth of each tree.

Author

Adam Kapelner