Skip to contents

Predictions are an aggregation from each of the individual trees' predictions based on the function passed into the model creation step. The default aggregation is the sample average for regression and the modal class for classification. You can set a custom aggregation method via the YARF_set_aggregation_method function.

Usage

# S3 method for class 'YARF'
predict(object, new_data, ...)

Arguments

object

A YARF model object.

new_data

A n* x p matrix where each row is an observation you wish to predict for. Here, p is the same length as the original training data.

...

Other methods passed to predict

Value

The yhat prediction for the new_data record(s).

Author

Kapelner