Skip to contents

Computes information about the "proximity" of observations within the YARF model. Given two datasets, information is computed for all pairs of observation.

Usage

proximity_info(yarf_mod, X, prox_single_node_calc_script = NULL)

Arguments

yarf_mod

A YARF model object.

X

A n* x p data frame where each row is an observation. If NULL (the default), then this parameter is set to the model's training data.

prox_single_node_calc_script

Script ...

Value

(For now, a list of raw information for rows in each dataset)

Author

Matt Olson