Skip to contents

Function which queries the YARF model about how many times the variables are used when splitting

Usage

query_variable_counts(yarf_mod, type = "splits")

Arguments

yarf_mod

The model in which to query

type

Either "trees" which counts the number of trees where each variable was used one (or more) times or "splits" which counts the number of times each variable was used across the whole model.

Value

A vector with length p, the number of variables considered in this YARF model, with either a binary value for type = "trees" or a count value for type = "splits".

Author

Adam Kapelner