Skip to contents

Function which queries the YARF model about the proportion of times the variables are used when splitting. This is a convenience method which merely normalizes the result of query_variable_counts.

Usage

query_variable_proportions_across_trees(yarf_mod, type = "splits")

Arguments

yarf_mod

The model in which to query

type

Either "trees" which computes the proportion of trees where each variable was used one (or more) times or "splits" which computes the proportion of times each variable was used across the whole model.

Value

A vector with length p, the number of variables considered in this YARF model, with values between 0 and 1.

Author

Adam Kapelner