Sets the number of cores for YARF to use for all operations which are multithreaded (e.g. model construction, prediction, etc)
Source:R/YARF_builders.R
set_YARF_num_cores.RdSets the number of cores for YARF to use for all operations which are multithreaded (e.g. model construction, prediction, etc)