Returns the shared initial portion of a string
Source:R/YARF_node_info.R
shared_initial_substring.RdGiven two strings, return the identical portion beginning from the first character and on.

R/YARF_node_info.R
shared_initial_substring.RdGiven two strings, return the identical portion beginning from the first character and on.