Skip to contents

Duplicates the settings of YARF model. Wait is TRUE, all verbose logging is turned off and serializing is turned off as well.

Usage

yarf_duplicate(yarf_mod, X = NULL, y = NULL)

Arguments

yarf_mod

The YARF model with settings you wish to duplicate

X

The training data as a data frame. Default is NULL indicating the original training data.

y

The training responses as numeric / integer / factor vector. Default is NULL indicating the original training responses.

Value

A newly fitted YARF model with the original settings and the supplied training data.

Author

Adam Kapelner