Prints out a messages reflecting the progress of the YARF model construction until completion.
Arguments
- yarf_mod
The yarf model object
- time_delay_in_seconds
Frequency of messages in seconds. Default is
5seconds. Minimum is 0.1.NULLindicates it is shown once and then it completes.- trail_pts
If non-null, it will plot a secondary window with only the trees in the last
trail_treesnumber of progress updates defined bytime_delay_in_secondsversus error which allows assessing the convergence more closely. Default is50.