Computes a response prediction for new data observation(s) for all trees (unaggregated).
Source:R/YARF_predicts.R
YARF_predict_all_trees.RdComputes a response prediction for new data observation(s) for all trees (unaggregated).
Arguments
- yarf_mod
A YARF model object.
- new_data
A n* x p data frame where each row is an observation you wish to predict for. Here, p is the same length as the original training data and
new_datahas the same column names. If a matrix object is passed in, it is automatically cast to a data frame. This may not always give you what you want.