Serializes the model so the user can use save and save.image to write it to a file that can be then loaded into another and/or future R session.
Source: R/YARF_builders.R
YARF_serialize.RdSerializes the model so the user can use save and save.image
to write it to a file that can be then loaded into another and/or future R session.