Computes the out-of-bag (OOB) predictions for the validation subset of the training data. This allows the user to try many different models while still leaving test data for true out-of-sample performance estimation.
Source:R/YARF_oob_and_validation.R
YARF_update_with_oob_validation_results.RdComputes the out-of-bag (OOB) predictions for the validation subset of the training data. This allows the user to try many different models while still leaving test data for true out-of-sample performance estimation.