Gets information about each tree: the number of nodes, number of leaves and maximum depth.
Source:R/YARF_queries.R
get_tree_num_nodes_leaves_max_depths.RdGets information about each tree: the number of nodes, number of leaves and maximum depth.
Value
A list with three integer vector components all of which have length equal to the
number of trees completes: (1) num_nodes has entries equal to the number of nodes
in each tree, (2) num_leaves has entries equal to the number of leaves (terminal
nodes) in each tree and (3) max_depths has entries equal to the maximum depth of
each tree.