Computes a response prediction for new data observation(s).
Source:R/YARF_predicts.R
predict.YARF.RdPredictions are an aggregation from each of the
individual trees' predictions based on the function passed into the model creation step. The default
aggregation is the sample average for regression and the modal class for classification. You can set
a custom aggregation method via the YARF_set_aggregation_method function.
Usage
# S3 method for class 'YARF'
predict(object, new_data, ...)