Function which queries the YARF model about the proportion of times the variables are used when splitting. This is a convenience method which merely normalizes the result of query_variable_counts.
Source: R/YARF_queries.R
query_variable_proportions_across_trees.RdFunction which queries the YARF model about the proportion of times the variables are used when splitting.
This is a convenience method which merely normalizes the result of query_variable_counts.